<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_TW">
<context>
    <name>AptConfigMessage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/AptConfigMessage.cpp" line="83"/>
        <source>Enter the number to configure: </source>
        <translation>請輸入序號進行配置：</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/AptConfigMessage.cpp" line="88"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>確 定</translation>
    </message>
</context>
<context>
    <name>BackendProcessPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/backendprocesspage.cpp" line="16"/>
        <source>Loading packages...</source>
        <translation>正在載入安裝包…</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/backendprocesspage.cpp" line="17"/>
        <source>%1/%2 loaded</source>
        <translation>已載入%1/%2</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/backendprocesspage.cpp" line="20"/>
        <source>Initializing...</source>
        <translation>正在初始化…</translation>
    </message>
</context>
<context>
    <name>DdimErrorPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/ddimerrorpage.cpp" line="17"/>
        <source>OK</source>
        <translation>確 定</translation>
    </message>
</context>
<context>
    <name>DebInstaller</name>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="101"/>
        <source>Package Installer</source>
        <translation>軟體包安裝器</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="109"/>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="130"/>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="537"/>
        <source>Installing other packages... Please open it later.</source>
        <translation>正在執行安裝流程，無法打開</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="541"/>
        <source>Parsing failed: An illegal file structure was found in the manifest file!</source>
        <translation>套裝軟體解析失敗，套裝軟體清單包含非法的文件結構！</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="543"/>
        <source>Parsing failed: An illegal version number was found in the manifest file!</source>
        <translation>套裝軟體解析失敗，套裝軟體清單包含非法版本號！</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="545"/>
        <source>No deb packages found. Please check the folder.</source>
        <translation>未檢測到安裝包，請檢查安裝目錄！</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="631"/>
        <source>The deb package may be broken</source>
        <translation>請檢查deb包是否損壞</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="639"/>
        <source>You can only install local deb packages</source>
        <translation>只能安裝本機的deb包</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="653"/>
        <source>Already Added</source>
        <translation>已添加</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="662"/>
        <source>%1 does not exist, please reselect</source>
        <translation>%1文件不存在，請重新選擇文件</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="330"/>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="669"/>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="799"/>
        <source>Bulk Install</source>
        <translation>批次安裝</translation>
    </message>
</context>
<context>
    <name>DebListModel</name>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="87"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="104"/>
        <source>Installation failed, please check your network connection</source>
        <translation>安裝失敗，請檢查網路連線</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="89"/>
        <source>Installation failed, please check for updates in Control Center</source>
        <translation>安裝失敗，請於控制中心檢查更新</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="92"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="96"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="108"/>
        <source>Installation failed, insufficient disk space</source>
        <translation>安裝失敗，磁碟機空間不足</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="113"/>
        <source>No digital signature</source>
        <translation>無數位簽章</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="117"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="632"/>
        <source>Invalid digital signature</source>
        <translation>數位簽章無效</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="124"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="625"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1576"/>
        <source>The administrator has set policies to prevent installation of this package</source>
        <translation>管理員已限制，該軟體禁止安裝</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="129"/>
        <source>Installation Failed</source>
        <translation>安裝失敗</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="634"/>
        <source>Failed to install %1</source>
        <translation>%1安裝失敗</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1617"/>
        <source>This package does not have a valid digital signature and has been blocked from installing/running. Go to Security Center &gt; Tools &gt; App Security to change the settings.</source>
        <translation>安裝包沒有有效的數位簽章，已被禁止安裝/執行，請前往安全中心-安全工具-應用安全進行調整。</translation>
    </message>
    <message>
        <source>Failed to install %1: no valid digital singature</source>
        <translation type="vanished">無法安裝%1，安裝包無有效的數位簽章</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="961"/>
        <source>Unable to install - no digital signature</source>
        <translation>無法安裝，安裝包無數位簽章</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="962"/>
        <source>Please go to Control Center to enable developer mode and try again. Proceed?</source>
        <translation>請進入控制中心，開啟開發者模式後，再嘗試繼續安裝。是否前往？</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="965"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1620"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>取 消</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="966"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1621"/>
        <source>Proceed</source>
        <comment>button</comment>
        <translation>前 往</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="919"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1021"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1578"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>確 定</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="923"/>
        <source>Failed to install %1: no valid digital signature</source>
        <translation>無法安裝%1，安裝包無有效的數位簽章</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1059"/>
        <source>This package does not have a valid digital signature. Continue with the installation?</source>
        <translation>此安裝包沒有有效的數位簽章，是否繼續安裝？</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1061"/>
        <source>Cancel</source>
        <translation>取 消</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1062"/>
        <source>Continue</source>
        <comment>button</comment>
        <translation>繼續</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="917"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1018"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1575"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1616"/>
        <source>Unable to install</source>
        <translation>無法安裝</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1019"/>
        <source>This package does not have a valid digital signature</source>
        <translation>此安裝包沒有有效的數位簽章</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="637"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="642"/>
        <source>Broken dependencies: %1</source>
        <translation>缺少依賴軟體：%1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="121"/>
        <source>Authentication failed</source>
        <translation>配置授權失敗</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="623"/>
        <source>Unmatched package architecture</source>
        <translation>軟體套件結構不符合規範</translation>
    </message>
</context>
<context>
    <name>FileChooseWidget</name>
    <message>
        <location filename="../src/deb-installer/view/widgets/filechoosewidget.cpp" line="60"/>
        <source>Drag deb packages here</source>
        <translation>拖曳軟體包到此</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/filechoosewidget.cpp" line="102"/>
        <source>Select File</source>
        <translation>選擇檔案</translation>
    </message>
</context>
<context>
    <name>MultipleInstallPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="33"/>
        <source>Show details</source>
        <translation>顯示詳細訊息</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="33"/>
        <source>Collapse</source>
        <comment>button</comment>
        <translation>隱 藏</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="171"/>
        <source>Install</source>
        <comment>button</comment>
        <translation>安 裝</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="172"/>
        <source>Done</source>
        <comment>button</comment>
        <translation>完 成</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="174"/>
        <source>Back</source>
        <comment>button</comment>
        <translation>返 回</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="468"/>
        <source>Dependencies in the repository</source>
        <translation>倉庫中存在的依賴包</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="474"/>
        <source>Missing dependencies</source>
        <translation>倉庫中缺失的依賴包</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="523"/>
        <source>Installing dependencies: %1</source>
        <translation>正在安裝依賴：%1</translation>
    </message>
</context>
<context>
    <name>PackageSelectItem</name>
    <message>
        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="82"/>
        <source>Same version installed</source>
        <translation>已安裝相同版本</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="85"/>
        <source>Earlier version installed: %1</source>
        <translation>已安裝舊版本：%1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="89"/>
        <source>Later version installed: %1</source>
        <translation>已安裝較新的版本：%1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="94"/>
        <source>Unmatched package architecture</source>
        <translation>軟體套件結構不符合規範</translation>
    </message>
</context>
<context>
    <name>PackageSelectView</name>
    <message>
        <location filename="../src/deb-installer/view/pages/packageselectview.cpp" line="19"/>
        <source>Select all</source>
        <translation>全選</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/packageselectview.cpp" line="20"/>
        <source>Install</source>
        <comment>button</comment>
        <translation>安 裝</translation>
    </message>
</context>
<context>
    <name>PackagesListDelegate</name>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="60"/>
        <source>Installing</source>
        <translation>正在安裝</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="64"/>
        <source>Installed</source>
        <translation>已安裝</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="72"/>
        <source>Failed</source>
        <translation>安裝失敗</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="68"/>
        <source>Waiting</source>
        <translation>等待安裝</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="231"/>
        <source>Same version installed</source>
        <translation>已安裝相同版本</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="234"/>
        <source>Later version installed: %1</source>
        <translation>已安裝較新的版本：%1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="237"/>
        <source>Earlier version installed: %1</source>
        <translation>已安裝舊版本：%1</translation>
    </message>
</context>
<context>
    <name>PackagesListView</name>
    <message>
        <location filename="../src/deb-installer/model/packagelistview.cpp" line="160"/>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="30"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="45"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="46"/>
        <source>Collapse</source>
        <comment>button</comment>
        <translation>隱 藏</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/deb-installer/view/pages/setting_translation.cpp" line="9"/>
        <source>Basic</source>
        <translation>基礎設定</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/setting_translation.cpp" line="10"/>
        <source>Check digital signatures if the developer mode is enabled</source>
        <translation>開發者模式下，檢測安裝包的簽名</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/settingdialog.cpp" line="77"/>
        <source>To install unsigned apps, go to Security Center &gt; Tools &gt; App Security, and select the app types that can be installed.</source>
        <translation>如需安裝未簽名應用，前往安全中心-安全工具-應用安全設定允許安裝的應用類型。</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/settingdialog.cpp" line="79"/>
        <source>Security Center &gt; Tools &gt; App Security</source>
        <translation>安全中心-安全工具-應用安全</translation>
    </message>
</context>
<context>
    <name>SingleInstallPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="707"/>
        <source>Collapse</source>
        <translation>隱藏</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="333"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="803"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="966"/>
        <source>Reinstall</source>
        <translation>重 裝</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="806"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="969"/>
        <source>Later version installed: %1</source>
        <translation>已安裝較新的版本：%1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="808"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="971"/>
        <source>Downgrade</source>
        <translation>安裝舊版本</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="811"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="974"/>
        <source>Earlier version installed: %1</source>
        <translation>已安裝舊版本：%1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="876"/>
        <source>Installing dependencies: %1</source>
        <translation>正在安裝依賴：%1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1011"/>
        <source>Failed to install %1</source>
        <translation>%1安裝失敗</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="178"/>
        <source>Version: </source>
        <translation>版本：</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="325"/>
        <source>Install</source>
        <comment>button</comment>
        <translation>安 裝</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="329"/>
        <source>Remove</source>
        <comment>button</comment>
        <translation>移 除</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="337"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>確 定</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="341"/>
        <source>Back</source>
        <comment>button</comment>
        <translation>返 回</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="345"/>
        <source>Done</source>
        <comment>button</comment>
        <translation>完 成</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="679"/>
        <source>Installed successfully</source>
        <translation>安裝成功</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="684"/>
        <source>Uninstalled successfully</source>
        <translation>解除安裝成功</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="698"/>
        <source>Uninstall Failed</source>
        <translation>解除安裝失敗</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="727"/>
        <source>Dependencies in the repository</source>
        <translation>倉庫中存在的依賴包</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="733"/>
        <source>Missing dependencies</source>
        <translation>倉庫中缺失的依賴包</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="813"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="976"/>
        <source>Update</source>
        <comment>button</comment>
        <translation>更 新</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1016"/>
        <source>Invalid digital signature</source>
        <translation>數位簽章無效</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="166"/>
        <source>Name: </source>
        <translation>名稱：</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="802"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="965"/>
        <source>Same version installed</source>
        <translation>已安裝相同版本</translation>
    </message>
</context>
<context>
    <name>SingleInstallPage_Install</name>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="45"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="526"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="551"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="678"/>
        <source>Show details</source>
        <translation>顯示詳細訊息</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="30"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="46"/>
        <source>Show dependencies</source>
        <translation>顯示依賴包關係</translation>
    </message>
</context>
<context>
    <name>SingleInstallPage_Uninstall</name>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="576"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="683"/>
        <source>Show details</source>
        <translation>顯示卸載進程</translation>
    </message>
</context>
<context>
    <name>UninstallConfirmPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="16"/>
        <source>Show related packages</source>
        <translation>顯示相關軟體包</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="16"/>
        <source>Collapse</source>
        <comment>button</comment>
        <translation>隱 藏</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="37"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>取 消</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="39"/>
        <source>Confirm</source>
        <translation>確 定</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="112"/>
        <source>Are you sure you want to uninstall %1?
All dependencies will also be removed</source>
        <translation>確定解除安裝 %1？
也會移除所有依賴</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="114"/>
        <source>Are you sure you want to uninstall %1?
The system or other applications may not work properly</source>
        <translation>您確定要移除%1嗎？
移除此軟體可能會導致系統或其他軟體無法正常使用</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../src/deb-installer/main.cpp" line="48"/>
        <location filename="../src/deb-installer/main.cpp" line="49"/>
        <source>Package Installer</source>
        <translation>軟體包安裝器</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/main.cpp" line="50"/>
        <source>Package Installer helps users install and remove local packages, and supports bulk installation.</source>
        <translation>軟體包安裝器用來幫助使用者安裝和移除本機軟體包。支援批次安裝。</translation>
    </message>
</context>
</TS>